@@ -5,11 +5,8 @@ pub(crate) mod context;
 pub(crate) mod options;
 
 use crate::{
-    error::{CompilationError, ErrorIterator},
-    keywords,
-    keywords::Validators,
-    paths::InstancePath,
-    resolver::Resolver,
+    error::ErrorIterator, keywords, keywords::Validators, paths::InstancePath, resolver::Resolver,
+    ValidationError,
 };
 use context::CompilationContext;
 use options::CompilationOptions;
@@ -46,6 +43,7 @@ impl<'a> JSONSchema<'a> {
     ///     .with_draft(Draft::Draft7)
     ///     .compile(&schema);
     /// ```
+    #[must_use]
     pub fn options() -> CompilationOptions {
         CompilationOptions::default()
     }
@@ -53,7 +51,7 @@ impl<'a> JSONSchema<'a> {
     /// Compile the input schema into a validation tree.
     ///
     /// The method is equivalent to `JSONSchema::options().compile(schema)`
-    pub fn compile(schema: &'a Value) -> Result<JSONSchema<'a>, CompilationError> {
+    pub fn compile(schema: &'a Value) -> Result<JSONSchema<'a>, ValidationError<'a>> {
         Self::options().compile(schema)
     }
 
@@ -86,10 +84,10 @@ impl<'a> JSONSchema<'a> {
 
 /// Compile JSON schema into a tree of validators.
 #[inline]
-pub(crate) fn compile_validators(
-    schema: &Value,
-    context: &CompilationContext,
-) -> Result<Validators, CompilationError> {
+pub(crate) fn compile_validators<'a, 'c>(
+    schema: &'a Value,
+    context: &'c CompilationContext,
+) -> Result<Validators, ValidationError<'a>> {
     let context = context.push(schema)?;
     match schema {
         Value::Bool(value) => match value {
@@ -104,7 +102,7 @@ pub(crate) fn compile_validators(
                     Ok(vec![keywords::ref_::compile(schema, reference, &context)
                         .expect("Should always return Some")?])
                 } else {
-                    Err(CompilationError::SchemaError)
+                    Err(ValidationError::schema(schema))
                 }
             } else {
                 let mut validators = Vec::with_capacity(object.len());
@@ -118,7 +116,7 @@ pub(crate) fn compile_validators(
                 Ok(validators)
             }
         }
-        _ => Err(CompilationError::SchemaError),
+        _ => Err(ValidationError::schema(schema)),
     }
 }
 
@@ -197,9 +195,6 @@ mod tests {
             errors[0].to_string(),
             r#"{"a":3} has less than 2 properties"#
         );
-        assert_eq!(
-            errors[1].to_string(),
-            r#"'"a"' is shorter than 3 characters"#
-        );
+        assert_eq!(errors[1].to_string(), r#""a" is shorter than 3 characters"#);
     }
 }
