@@ -7,45 +7,13 @@ use serde_json::{Map, Number, Value};
 use std::{
     borrow::Cow,
     error, fmt,
-    fmt::{Error, Formatter},
+    fmt::Formatter,
     io,
     iter::{empty, once},
     str::Utf8Error,
     string::FromUtf8Error,
 };
 
-/// The error type that happens when the input schema is not valid.
-///
-/// It includes cases when during validation a reference is resolved into an invalid schema,
-/// which we can't know upfront because schemas can be in remote locations.
-#[derive(Debug, PartialEq)]
-pub enum CompilationError {
-    /// Invalid schema structure
-    SchemaError,
-}
-
-impl error::Error for CompilationError {}
-
-impl fmt::Display for CompilationError {
-    #[inline]
-    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error> {
-        write!(f, "Schema compilation error")
-    }
-}
-
-impl From<regex::Error> for CompilationError {
-    #[inline]
-    fn from(_: regex::Error) -> Self {
-        CompilationError::SchemaError
-    }
-}
-impl From<url::ParseError> for CompilationError {
-    #[inline]
-    fn from(_: url::ParseError) -> Self {
-        CompilationError::SchemaError
-    }
-}
-
 /// An error that can occur during validation.
 #[derive(Debug)]
 pub struct ValidationError<'a> {
@@ -98,13 +66,15 @@ pub enum ValidationErrorKind {
     AdditionalProperties { unexpected: Vec<String> },
     /// The input value is not valid under any of the given schemas.
     AnyOf,
+    /// Results from a [`fancy_regex::Error::BacktrackLimitExceeded`] variant when matching
+    BacktrackLimitExceeded { error: fancy_regex::Error },
     /// The input value doesn't match expected constant.
     Constant { expected_value: Value },
     /// The input array doesn't contain items conforming to the specified schema.
     Contains,
-    /// Ths input value does not respect the defined contentEncoding
+    /// The input value does not respect the defined contentEncoding
     ContentEncoding { content_encoding: String },
-    /// Ths input value does not respect the defined contentMediaType
+    /// The input value does not respect the defined contentMediaType
     ContentMediaType { content_media_type: String },
     /// The input value doesn't match any of specified options.
     Enum { options: Value },
@@ -159,7 +129,7 @@ pub enum ValidationErrorKind {
         error: Box<ValidationError<'static>>,
     },
     /// When a required property is missing.
-    Required { property: String },
+    Required { property: Value },
     /// Any error that happens during network request via `reqwest` crate
     #[cfg(any(feature = "reqwest", test))]
     Reqwest { error: reqwest::Error },
@@ -190,7 +160,7 @@ impl<'a> ValidationError<'a> {
         }
     }
 
-    pub(crate) fn additional_items(
+    pub(crate) const fn additional_items(
         instance_path: JSONPointer,
         instance: &'a Value,
         limit: usize,
@@ -212,13 +182,27 @@ impl<'a> ValidationError<'a> {
             kind: ValidationErrorKind::AdditionalProperties { unexpected },
         }
     }
-    pub(crate) fn any_of(instance_path: JSONPointer, instance: &'a Value) -> ValidationError<'a> {
+    pub(crate) const fn any_of(
+        instance_path: JSONPointer,
+        instance: &'a Value,
+    ) -> ValidationError<'a> {
         ValidationError {
             instance_path,
             instance: Cow::Borrowed(instance),
             kind: ValidationErrorKind::AnyOf,
         }
     }
+    pub(crate) const fn backtrack_limit(
+        instance_path: JSONPointer,
+        instance: &'a Value,
+        error: fancy_regex::Error,
+    ) -> ValidationError<'a> {
+        ValidationError {
+            instance_path,
+            instance: Cow::Borrowed(instance),
+            kind: ValidationErrorKind::BacktrackLimitExceeded { error },
+        }
+    }
     pub(crate) fn constant_array(
         instance_path: JSONPointer,
         instance: &'a Value,
@@ -232,7 +216,7 @@ impl<'a> ValidationError<'a> {
             },
         }
     }
-    pub(crate) fn constant_boolean(
+    pub(crate) const fn constant_boolean(
         instance_path: JSONPointer,
         instance: &'a Value,
         expected_value: bool,
@@ -245,7 +229,7 @@ impl<'a> ValidationError<'a> {
             },
         }
     }
-    pub(crate) fn constant_null(
+    pub(crate) const fn constant_null(
         instance_path: JSONPointer,
         instance: &'a Value,
     ) -> ValidationError<'a> {
@@ -296,7 +280,10 @@ impl<'a> ValidationError<'a> {
             },
         }
     }
-    pub(crate) fn contains(instance_path: JSONPointer, instance: &'a Value) -> ValidationError<'a> {
+    pub(crate) const fn contains(
+        instance_path: JSONPointer,
+        instance: &'a Value,
+    ) -> ValidationError<'a> {
         ValidationError {
             instance_path,
             instance: Cow::Borrowed(instance),
@@ -342,7 +329,7 @@ impl<'a> ValidationError<'a> {
             },
         }
     }
-    pub(crate) fn exclusive_maximum(
+    pub(crate) const fn exclusive_maximum(
         instance_path: JSONPointer,
         instance: &'a Value,
         limit: f64,
@@ -353,7 +340,7 @@ impl<'a> ValidationError<'a> {
             kind: ValidationErrorKind::ExclusiveMaximum { limit },
         }
     }
-    pub(crate) fn exclusive_minimum(
+    pub(crate) const fn exclusive_minimum(
         instance_path: JSONPointer,
         instance: &'a Value,
         limit: f64,
@@ -364,7 +351,7 @@ impl<'a> ValidationError<'a> {
             kind: ValidationErrorKind::ExclusiveMinimum { limit },
         }
     }
-    pub(crate) fn false_schema(
+    pub(crate) const fn false_schema(
         instance_path: JSONPointer,
         instance: &'a Value,
     ) -> ValidationError<'a> {
@@ -381,7 +368,7 @@ impl<'a> ValidationError<'a> {
             kind: ValidationErrorKind::FileNotFound { error },
         }
     }
-    pub(crate) fn format(
+    pub(crate) const fn format(
         instance_path: JSONPointer,
         instance: &'a Value,
         format: &'static str,
@@ -420,7 +407,7 @@ impl<'a> ValidationError<'a> {
             kind: ValidationErrorKind::InvalidURL { error },
         }
     }
-    pub(crate) fn max_items(
+    pub(crate) const fn max_items(
         instance_path: JSONPointer,
         instance: &'a Value,
         limit: u64,
@@ -431,7 +418,7 @@ impl<'a> ValidationError<'a> {
             kind: ValidationErrorKind::MaxItems { limit },
         }
     }
-    pub(crate) fn maximum(
+    pub(crate) const fn maximum(
         instance_path: JSONPointer,
         instance: &'a Value,
         limit: f64,
@@ -442,7 +429,7 @@ impl<'a> ValidationError<'a> {
             kind: ValidationErrorKind::Maximum { limit },
         }
     }
-    pub(crate) fn max_length(
+    pub(crate) const fn max_length(
         instance_path: JSONPointer,
         instance: &'a Value,
         limit: u64,
@@ -453,7 +440,7 @@ impl<'a> ValidationError<'a> {
             kind: ValidationErrorKind::MaxLength { limit },
         }
     }
-    pub(crate) fn max_properties(
+    pub(crate) const fn max_properties(
         instance_path: JSONPointer,
         instance: &'a Value,
         limit: u64,
@@ -464,7 +451,7 @@ impl<'a> ValidationError<'a> {
             kind: ValidationErrorKind::MaxProperties { limit },
         }
     }
-    pub(crate) fn min_items(
+    pub(crate) const fn min_items(
         instance_path: JSONPointer,
         instance: &'a Value,
         limit: u64,
@@ -475,7 +462,7 @@ impl<'a> ValidationError<'a> {
             kind: ValidationErrorKind::MinItems { limit },
         }
     }
-    pub(crate) fn minimum(
+    pub(crate) const fn minimum(
         instance_path: JSONPointer,
         instance: &'a Value,
         limit: f64,
@@ -486,7 +473,7 @@ impl<'a> ValidationError<'a> {
             kind: ValidationErrorKind::Minimum { limit },
         }
     }
-    pub(crate) fn min_length(
+    pub(crate) const fn min_length(
         instance_path: JSONPointer,
         instance: &'a Value,
         limit: u64,
@@ -497,7 +484,7 @@ impl<'a> ValidationError<'a> {
             kind: ValidationErrorKind::MinLength { limit },
         }
     }
-    pub(crate) fn min_properties(
+    pub(crate) const fn min_properties(
         instance_path: JSONPointer,
         instance: &'a Value,
         limit: u64,
@@ -508,7 +495,7 @@ impl<'a> ValidationError<'a> {
             kind: ValidationErrorKind::MinProperties { limit },
         }
     }
-    pub(crate) fn multiple_of(
+    pub(crate) const fn multiple_of(
         instance_path: JSONPointer,
         instance: &'a Value,
         multiple_of: f64,
@@ -519,7 +506,7 @@ impl<'a> ValidationError<'a> {
             kind: ValidationErrorKind::MultipleOf { multiple_of },
         }
     }
-    pub(crate) fn not(
+    pub(crate) const fn not(
         instance_path: JSONPointer,
         instance: &'a Value,
         schema: Value,
@@ -530,7 +517,7 @@ impl<'a> ValidationError<'a> {
             kind: ValidationErrorKind::Not { schema },
         }
     }
-    pub(crate) fn one_of_multiple_valid(
+    pub(crate) const fn one_of_multiple_valid(
         instance_path: JSONPointer,
         instance: &'a Value,
     ) -> ValidationError<'a> {
@@ -540,7 +527,7 @@ impl<'a> ValidationError<'a> {
             kind: ValidationErrorKind::OneOfMultipleValid,
         }
     }
-    pub(crate) fn one_of_not_valid(
+    pub(crate) const fn one_of_not_valid(
         instance_path: JSONPointer,
         instance: &'a Value,
     ) -> ValidationError<'a> {
@@ -550,7 +537,7 @@ impl<'a> ValidationError<'a> {
             kind: ValidationErrorKind::OneOfNotValid,
         }
     }
-    pub(crate) fn pattern(
+    pub(crate) const fn pattern(
         instance_path: JSONPointer,
         instance: &'a Value,
         pattern: String,
@@ -574,10 +561,10 @@ impl<'a> ValidationError<'a> {
             },
         }
     }
-    pub(crate) fn required(
+    pub(crate) const fn required(
         instance_path: JSONPointer,
         instance: &'a Value,
-        property: String,
+        property: Value,
     ) -> ValidationError<'a> {
         ValidationError {
             instance_path,
@@ -593,14 +580,24 @@ impl<'a> ValidationError<'a> {
             kind: ValidationErrorKind::Reqwest { error },
         }
     }
-    pub(crate) fn schema() -> ValidationError<'a> {
+
+    pub(crate) fn schema(instance: &'a Value) -> ValidationError<'a> {
+        ValidationError {
+            instance_path: JSONPointer::default(),
+            instance: Cow::Borrowed(instance),
+            kind: ValidationErrorKind::Schema,
+        }
+    }
+
+    pub(crate) fn null_schema() -> ValidationError<'a> {
         ValidationError {
             instance_path: JSONPointer::default(),
             instance: Cow::Owned(Value::Null),
             kind: ValidationErrorKind::Schema,
         }
     }
-    pub(crate) fn single_type_error(
+
+    pub(crate) const fn single_type_error(
         instance_path: JSONPointer,
         instance: &'a Value,
         type_name: PrimitiveType,
@@ -613,7 +610,7 @@ impl<'a> ValidationError<'a> {
             },
         }
     }
-    pub(crate) fn multiple_type_error(
+    pub(crate) const fn multiple_type_error(
         instance_path: JSONPointer,
         instance: &'a Value,
         types: PrimitiveTypesBitMap,
@@ -626,7 +623,7 @@ impl<'a> ValidationError<'a> {
             },
         }
     }
-    pub(crate) fn unique_items(
+    pub(crate) const fn unique_items(
         instance_path: JSONPointer,
         instance: &'a Value,
     ) -> ValidationError<'a> {
@@ -652,12 +649,6 @@ impl<'a> ValidationError<'a> {
     }
 }
 
-impl From<CompilationError> for ValidationError<'_> {
-    #[inline]
-    fn from(_: CompilationError) -> Self {
-        ValidationError::schema()
-    }
-}
 impl error::Error for ValidationError<'_> {}
 impl From<serde_json::Error> for ValidationError<'_> {
     #[inline]
@@ -709,11 +700,12 @@ impl fmt::Display for ValidationError<'_> {
             ValidationErrorKind::Reqwest { error } => write!(f, "{}", error),
             ValidationErrorKind::FileNotFound { error } => write!(f, "{}", error),
             ValidationErrorKind::InvalidURL { error } => write!(f, "{}", error),
+            ValidationErrorKind::BacktrackLimitExceeded { error } => write!(f, "{}", error),
             ValidationErrorKind::UnknownReferenceScheme { scheme } => {
                 write!(f, "Unknown scheme: {}", scheme)
             }
             ValidationErrorKind::Format { format } => {
-                write!(f, "'{}' is not a '{}'", self.instance, format)
+                write!(f, r#"{} is not a "{}""#, self.instance, format)
             }
             ValidationErrorKind::AdditionalItems { limit } => {
                 // It's safe to unwrap here as ValidationErrorKind::AdditionalItems is reported only in
@@ -764,35 +756,35 @@ impl fmt::Display for ValidationError<'_> {
             }
             ValidationErrorKind::AnyOf | ValidationErrorKind::OneOfNotValid => write!(
                 f,
-                "'{}' is not valid under any of the given schemas",
+                "{} is not valid under any of the given schemas",
                 self.instance
             ),
             ValidationErrorKind::Contains => write!(
                 f,
-                "None of '{}' are valid under the given schema",
+                "None of {} are valid under the given schema",
                 self.instance
             ),
             ValidationErrorKind::Constant { expected_value } => {
-                write!(f, "'{}' was expected", expected_value)
+                write!(f, "{} was expected", expected_value)
             }
             ValidationErrorKind::ContentEncoding { content_encoding } => {
                 write!(
                     f,
-                    "'{}' is not compliant with encoding={}",
+                    r#"{} is not compliant with "{}" content encoding"#,
                     self.instance, content_encoding
                 )
             }
             ValidationErrorKind::ContentMediaType { content_media_type } => {
                 write!(
                     f,
-                    "'{}' is not compliant with media_type={}",
+                    r#"{} is not compliant with "{}" media type"#,
                     self.instance, content_media_type
                 )
             }
             ValidationErrorKind::FromUtf8 { error } => write!(f, "{}", error),
             ValidationErrorKind::Utf8 { error } => write!(f, "{}", error),
             ValidationErrorKind::Enum { options } => {
-                write!(f, "'{}' is not one of '{}'", self.instance, options)
+                write!(f, "{} is not one of {}", self.instance, options)
             }
             ValidationErrorKind::ExclusiveMaximum { limit } => write!(
                 f,
@@ -805,7 +797,7 @@ impl fmt::Display for ValidationError<'_> {
                 self.instance, limit
             ),
             ValidationErrorKind::FalseSchema => {
-                write!(f, "False schema does not allow '{}'", self.instance)
+                write!(f, "False schema does not allow {}", self.instance)
             }
             ValidationErrorKind::InvalidReference { reference } => {
                 write!(f, "Invalid reference: {}", reference)
@@ -820,14 +812,14 @@ impl fmt::Display for ValidationError<'_> {
             }
             ValidationErrorKind::MaxLength { limit } => write!(
                 f,
-                "'{}' is longer than {} character{}",
+                "{} is longer than {} character{}",
                 self.instance,
                 limit,
                 if *limit == 1 { "" } else { "s" }
             ),
             ValidationErrorKind::MinLength { limit } => write!(
                 f,
-                "'{}' is shorter than {} character{}",
+                "{} is shorter than {} character{}",
                 self.instance,
                 limit,
                 if *limit == 1 { "" } else { "s" }
@@ -865,36 +857,36 @@ impl fmt::Display for ValidationError<'_> {
             }
             ValidationErrorKind::OneOfMultipleValid => write!(
                 f,
-                "'{}' is valid under more than one of the given schemas",
+                "{} is valid under more than one of the given schemas",
                 self.instance
             ),
             ValidationErrorKind::Pattern { pattern } => {
-                write!(f, "'{}' does not match '{}'", self.instance, pattern)
+                write!(f, r#"{} does not match "{}""#, self.instance, pattern)
             }
             ValidationErrorKind::PropertyNames { error } => {
                 write!(f, "{}", error.to_string())
             }
             ValidationErrorKind::Required { property } => {
-                write!(f, "'{}' is a required property", property)
+                write!(f, "{} is a required property", property)
             }
             ValidationErrorKind::MultipleOf { multiple_of } => {
                 write!(f, "{} is not a multiple of {}", self.instance, multiple_of)
             }
             ValidationErrorKind::UniqueItems => {
-                write!(f, "'{}' has non-unique elements", self.instance)
+                write!(f, "{} has non-unique elements", self.instance)
             }
             ValidationErrorKind::Type {
                 kind: TypeKind::Single(type_),
-            } => write!(f, "'{}' is not of type '{}'", self.instance, type_),
+            } => write!(f, r#"{} is not of type "{}""#, self.instance, type_),
             ValidationErrorKind::Type {
                 kind: TypeKind::Multiple(types),
             } => write!(
                 f,
-                "'{}' is not of types {}",
+                "{} is not of types {}",
                 self.instance,
                 types
                     .into_iter()
-                    .map(|t| format!("'{}'", t))
+                    .map(|t| format!(r#""{}""#, t))
                     .collect::<Vec<String>>()
                     .join(", ")
             ),
@@ -917,7 +909,7 @@ mod tests {
             &instance,
             PrimitiveType::String,
         );
-        assert_eq!(err.to_string(), "'42' is not of type 'string'")
+        assert_eq!(err.to_string(), r#"42 is not of type "string""#)
     }
 
     #[test]
@@ -928,7 +920,7 @@ mod tests {
             &instance,
             vec![PrimitiveType::String, PrimitiveType::Number].into(),
         );
-        assert_eq!(err.to_string(), "'42' is not of types 'number', 'string'")
+        assert_eq!(err.to_string(), r#"42 is not of types "number", "string""#)
     }
 
     #[test_case(true, &json!({"foo": {"bar": 42}}), &["foo", "bar"])]
@@ -961,9 +953,9 @@ mod tests {
     }
 
     #[test_case(true, &json!([1, {"foo": ["42"]}]), &[PathChunk::Index(0)])]
-    #[test_case(true, &json!(["a", {"foo": [42]}]), &[PathChunk::Index(1), PathChunk::Name("foo".to_string()), PathChunk::Index(0)])]
+    #[test_case(true, &json!(["a", {"foo": [42]}]), &[PathChunk::Index(1), PathChunk::Property("foo".to_string()), PathChunk::Index(0)])]
     #[test_case(false, &json!([1, {"foo": ["42"]}]), &[PathChunk::Index(0)])]
-    #[test_case(false, &json!(["a", {"foo": [42]}]), &[PathChunk::Index(1), PathChunk::Name("foo".to_string()), PathChunk::Index(0)])]
+    #[test_case(false, &json!(["a", {"foo": [42]}]), &[PathChunk::Index(1), PathChunk::Property("foo".to_string()), PathChunk::Index(0)])]
     fn instance_path_properties_and_arrays(
         additional_items: bool,
         instance: &Value,
