@@ -1,6 +1,6 @@
 use crate::{
     compilation::{compile_validators, context::CompilationContext, JSONSchema},
-    error::{error, no_error, CompilationError, ErrorIterator, ValidationError},
+    error::{error, no_error, ErrorIterator, ValidationError},
     keywords::{boolean::FalseValidator, format_validators, CompilationResult, Validators},
     paths::InstancePath,
     validator::Validate,
@@ -13,11 +13,11 @@ pub(crate) struct AdditionalItemsObjectValidator {
 }
 impl AdditionalItemsObjectValidator {
     #[inline]
-    pub(crate) fn compile(
-        schema: &Value,
+    pub(crate) fn compile<'a>(
+        schema: &'a Value,
         items_count: usize,
         context: &CompilationContext,
-    ) -> CompilationResult {
+    ) -> CompilationResult<'a> {
         let validators = compile_validators(schema, context)?;
         Ok(Box::new(AdditionalItemsObjectValidator {
             validators,
@@ -72,7 +72,7 @@ pub(crate) struct AdditionalItemsBooleanValidator {
 }
 impl AdditionalItemsBooleanValidator {
     #[inline]
-    pub(crate) fn compile(items_count: usize) -> CompilationResult {
+    pub(crate) fn compile<'a>(items_count: usize) -> CompilationResult<'a> {
         Ok(Box::new(AdditionalItemsBooleanValidator { items_count }))
     }
 }
@@ -111,11 +111,11 @@ impl ToString for AdditionalItemsBooleanValidator {
 }
 
 #[inline]
-pub(crate) fn compile(
+pub(crate) fn compile<'a>(
     parent: &Map<String, Value>,
-    schema: &Value,
+    schema: &'a Value,
     context: &CompilationContext,
-) -> Option<CompilationResult> {
+) -> Option<CompilationResult<'a>> {
     if let Some(items) = parent.get("items") {
         match items {
             Value::Object(_) => None,
@@ -140,7 +140,7 @@ pub(crate) fn compile(
                     Some(FalseValidator::compile())
                 }
             }
-            _ => Some(Err(CompilationError::SchemaError)),
+            _ => Some(Err(ValidationError::schema(schema))),
         }
     } else {
         None
