@@ -8,13 +8,13 @@
 //! Each valid combination of these keywords has a validator here.
 use crate::{
     compilation::{compile_validators, context::CompilationContext, JSONSchema},
-    error::{error, no_error, CompilationError, ErrorIterator, ValidationError},
+    error::{error, no_error, ErrorIterator, ValidationError},
     keywords::{format_validators, CompilationResult, Validators},
     paths::InstancePath,
     validator::Validate,
 };
 use ahash::AHashMap;
-use regex::Regex;
+use fancy_regex::Regex;
 use serde_json::{Map, Value};
 
 pub(crate) type PatternedValidators = Vec<(Regex, Validators)>;
@@ -76,7 +76,7 @@ macro_rules! dynamic_map {
                 ))
             }
         } else {
-            Some(Err(CompilationError::SchemaError))
+            Some(Err(ValidationError::null_schema()))
         }
     }};
 }
@@ -106,7 +106,7 @@ macro_rules! is_valid_patterns {
         let mut has_match = false;
         for (re, validators) in $patterns {
             // If there is a match, then the value should match the sub-schema
-            if re.is_match($property) {
+            if re.is_match($property).unwrap_or(false) {
                 has_match = true;
                 is_valid_pattern_schema!(validators, $schema, $value)
             }
@@ -127,20 +127,20 @@ macro_rules! validate {
     }};
 }
 
-fn compile_small_map(
-    map: &Map<String, Value>,
+fn compile_small_map<'a>(
+    map: &'a Map<String, Value>,
     context: &CompilationContext,
-) -> Result<SmallValidatorsMap, CompilationError> {
+) -> Result<SmallValidatorsMap, ValidationError<'a>> {
     let mut properties = Vec::with_capacity(map.len());
     for (key, subschema) in map {
         properties.push((key.clone(), compile_validators(subschema, context)?));
     }
     Ok(properties)
 }
-fn compile_big_map(
-    map: &Map<String, Value>,
+fn compile_big_map<'a>(
+    map: &'a Map<String, Value>,
     context: &CompilationContext,
-) -> Result<BigValidatorsMap, CompilationError> {
+) -> Result<BigValidatorsMap, ValidationError<'a>> {
     let mut properties = AHashMap::with_capacity(map.len());
     for (key, subschema) in map {
         properties.insert(key.clone(), compile_validators(subschema, context)?);
@@ -168,7 +168,10 @@ pub(crate) struct AdditionalPropertiesValidator {
 }
 impl AdditionalPropertiesValidator {
     #[inline]
-    pub(crate) fn compile(schema: &Value, context: &CompilationContext) -> CompilationResult {
+    pub(crate) fn compile<'a>(
+        schema: &'a Value,
+        context: &CompilationContext,
+    ) -> CompilationResult<'a> {
         Ok(Box::new(AdditionalPropertiesValidator {
             validators: compile_validators(schema, context)?,
         }))
@@ -231,7 +234,7 @@ impl ToString for AdditionalPropertiesValidator {
 pub(crate) struct AdditionalPropertiesFalseValidator {}
 impl AdditionalPropertiesFalseValidator {
     #[inline]
-    pub(crate) fn compile() -> CompilationResult {
+    pub(crate) fn compile<'a>() -> CompilationResult<'a> {
         Ok(Box::new(AdditionalPropertiesFalseValidator {}))
     }
 }
@@ -287,10 +290,10 @@ pub(crate) struct AdditionalPropertiesNotEmptyFalseValidator<M: PropertiesValida
 }
 impl AdditionalPropertiesNotEmptyFalseValidator<SmallValidatorsMap> {
     #[inline]
-    pub(crate) fn compile(
-        map: &Map<String, Value>,
+    pub(crate) fn compile<'a>(
+        map: &'a Map<String, Value>,
         context: &CompilationContext,
-    ) -> CompilationResult {
+    ) -> CompilationResult<'a> {
         Ok(Box::new(AdditionalPropertiesNotEmptyFalseValidator {
             properties: compile_small_map(map, context)?,
         }))
@@ -298,10 +301,10 @@ impl AdditionalPropertiesNotEmptyFalseValidator<SmallValidatorsMap> {
 }
 impl AdditionalPropertiesNotEmptyFalseValidator<BigValidatorsMap> {
     #[inline]
-    pub(crate) fn compile(
-        map: &Map<String, Value>,
+    pub(crate) fn compile<'a>(
+        map: &'a Map<String, Value>,
         context: &CompilationContext,
-    ) -> CompilationResult {
+    ) -> CompilationResult<'a> {
         Ok(Box::new(AdditionalPropertiesNotEmptyFalseValidator {
             properties: compile_big_map(map, context)?,
         }))
@@ -385,11 +388,11 @@ pub(crate) struct AdditionalPropertiesNotEmptyValidator<M: PropertiesValidatorsM
 }
 impl AdditionalPropertiesNotEmptyValidator<SmallValidatorsMap> {
     #[inline]
-    pub(crate) fn compile(
-        map: &Map<String, Value>,
-        schema: &Value,
+    pub(crate) fn compile<'a>(
+        map: &'a Map<String, Value>,
+        schema: &'a Value,
         context: &CompilationContext,
-    ) -> CompilationResult {
+    ) -> CompilationResult<'a> {
         Ok(Box::new(AdditionalPropertiesNotEmptyValidator {
             properties: compile_small_map(map, context)?,
             validators: compile_validators(schema, context)?,
@@ -398,11 +401,11 @@ impl AdditionalPropertiesNotEmptyValidator<SmallValidatorsMap> {
 }
 impl AdditionalPropertiesNotEmptyValidator<BigValidatorsMap> {
     #[inline]
-    pub(crate) fn compile(
-        map: &Map<String, Value>,
-        schema: &Value,
+    pub(crate) fn compile<'a>(
+        map: &'a Map<String, Value>,
+        schema: &'a Value,
         context: &CompilationContext,
-    ) -> CompilationResult {
+    ) -> CompilationResult<'a> {
         Ok(Box::new(AdditionalPropertiesNotEmptyValidator {
             properties: compile_big_map(map, context)?,
             validators: compile_validators(schema, context)?,
@@ -499,11 +502,11 @@ pub(crate) struct AdditionalPropertiesWithPatternsValidator {
 }
 impl AdditionalPropertiesWithPatternsValidator {
     #[inline]
-    pub(crate) fn compile(
-        schema: &Value,
+    pub(crate) fn compile<'a>(
+        schema: &'a Value,
         patterns: PatternedValidators,
         context: &CompilationContext,
-    ) -> CompilationResult {
+    ) -> CompilationResult<'a> {
         Ok(Box::new(AdditionalPropertiesWithPatternsValidator {
             validators: compile_validators(schema, context)?,
             patterns,
@@ -516,7 +519,7 @@ impl Validate for AdditionalPropertiesWithPatternsValidator {
             for (property, value) in item.iter() {
                 let mut has_match = false;
                 for (re, validators) in &self.patterns {
-                    if re.is_match(property) {
+                    if re.is_match(property).unwrap_or(false) {
                         has_match = true;
                         is_valid_pattern_schema!(validators, schema, value)
                     }
@@ -542,7 +545,7 @@ impl Validate for AdditionalPropertiesWithPatternsValidator {
                 errors.extend(
                     self.patterns
                         .iter()
-                        .filter(|(re, _)| re.is_match(property))
+                        .filter(|(re, _)| re.is_match(property).unwrap_or(false))
                         .flat_map(|(_, validators)| {
                             has_match = true;
                             validate!(validators, schema, value, instance_path, property)
@@ -600,7 +603,7 @@ pub(crate) struct AdditionalPropertiesWithPatternsFalseValidator {
 }
 impl AdditionalPropertiesWithPatternsFalseValidator {
     #[inline]
-    pub(crate) fn compile(patterns: PatternedValidators) -> CompilationResult {
+    pub(crate) fn compile<'a>(patterns: PatternedValidators) -> CompilationResult<'a> {
         Ok(Box::new(AdditionalPropertiesWithPatternsFalseValidator {
             patterns,
         }))
@@ -631,7 +634,7 @@ impl Validate for AdditionalPropertiesWithPatternsFalseValidator {
                 errors.extend(
                     self.patterns
                         .iter()
-                        .filter(|(re, _)| re.is_match(property))
+                        .filter(|(re, _)| re.is_match(property).unwrap_or(false))
                         .flat_map(|(_, validators)| {
                             has_match = true;
                             validate!(validators, schema, value, instance_path, property)
@@ -694,12 +697,12 @@ pub(crate) struct AdditionalPropertiesWithPatternsNotEmptyValidator<M: Propertie
 }
 impl AdditionalPropertiesWithPatternsNotEmptyValidator<SmallValidatorsMap> {
     #[inline]
-    pub(crate) fn compile(
-        map: &Map<String, Value>,
-        schema: &Value,
+    pub(crate) fn compile<'a>(
+        map: &'a Map<String, Value>,
+        schema: &'a Value,
         patterns: PatternedValidators,
         context: &CompilationContext,
-    ) -> CompilationResult {
+    ) -> CompilationResult<'a> {
         Ok(Box::new(
             AdditionalPropertiesWithPatternsNotEmptyValidator {
                 validators: compile_validators(schema, context)?,
@@ -711,12 +714,12 @@ impl AdditionalPropertiesWithPatternsNotEmptyValidator<SmallValidatorsMap> {
 }
 impl AdditionalPropertiesWithPatternsNotEmptyValidator<BigValidatorsMap> {
     #[inline]
-    pub(crate) fn compile(
-        map: &Map<String, Value>,
-        schema: &Value,
+    pub(crate) fn compile<'a>(
+        map: &'a Map<String, Value>,
+        schema: &'a Value,
         patterns: PatternedValidators,
         context: &CompilationContext,
-    ) -> CompilationResult {
+    ) -> CompilationResult<'a> {
         Ok(Box::new(
             AdditionalPropertiesWithPatternsNotEmptyValidator {
                 validators: compile_validators(schema, context)?,
@@ -735,7 +738,7 @@ impl<M: PropertiesValidatorsMap> Validate for AdditionalPropertiesWithPatternsNo
                         // Valid for `properties`, check `patternProperties`
                         for (re, validators) in &self.patterns {
                             // If there is a match, then the value should match the sub-schema
-                            if re.is_match(property) {
+                            if re.is_match(property).unwrap_or(false) {
                                 is_valid_pattern_schema!(validators, schema, value)
                             }
                         }
@@ -747,7 +750,7 @@ impl<M: PropertiesValidatorsMap> Validate for AdditionalPropertiesWithPatternsNo
                     let mut has_match = false;
                     for (re, validators) in &self.patterns {
                         // If there is a match, then the value should match the sub-schema
-                        if re.is_match(property) {
+                        if re.is_match(property).unwrap_or(false) {
                             has_match = true;
                             is_valid_pattern_schema!(validators, schema, value)
                         }
@@ -777,7 +780,7 @@ impl<M: PropertiesValidatorsMap> Validate for AdditionalPropertiesWithPatternsNo
                     errors.extend(
                         self.patterns
                             .iter()
-                            .filter(|(re, _)| re.is_match(property))
+                            .filter(|(re, _)| re.is_match(property).unwrap_or(false))
                             .flat_map(|(_, validators)| {
                                 validate!(validators, schema, value, instance_path, name)
                             }),
@@ -787,7 +790,7 @@ impl<M: PropertiesValidatorsMap> Validate for AdditionalPropertiesWithPatternsNo
                     errors.extend(
                         self.patterns
                             .iter()
-                            .filter(|(re, _)| re.is_match(property))
+                            .filter(|(re, _)| re.is_match(property).unwrap_or(false))
                             .flat_map(|(_, validators)| {
                                 has_match = true;
                                 validate!(validators, schema, value, instance_path, property)
@@ -851,11 +854,11 @@ pub(crate) struct AdditionalPropertiesWithPatternsNotEmptyFalseValidator<M: Prop
 }
 impl AdditionalPropertiesWithPatternsNotEmptyFalseValidator<SmallValidatorsMap> {
     #[inline]
-    pub(crate) fn compile(
-        map: &Map<String, Value>,
+    pub(crate) fn compile<'a>(
+        map: &'a Map<String, Value>,
         patterns: PatternedValidators,
         context: &CompilationContext,
-    ) -> CompilationResult {
+    ) -> CompilationResult<'a> {
         Ok(Box::new(
             AdditionalPropertiesWithPatternsNotEmptyFalseValidator::<SmallValidatorsMap> {
                 properties: compile_small_map(map, context)?,
@@ -866,11 +869,11 @@ impl AdditionalPropertiesWithPatternsNotEmptyFalseValidator<SmallValidatorsMap>
 }
 impl AdditionalPropertiesWithPatternsNotEmptyFalseValidator<BigValidatorsMap> {
     #[inline]
-    pub(crate) fn compile(
-        map: &Map<String, Value>,
+    pub(crate) fn compile<'a>(
+        map: &'a Map<String, Value>,
         patterns: PatternedValidators,
         context: &CompilationContext,
-    ) -> CompilationResult {
+    ) -> CompilationResult<'a> {
         Ok(Box::new(
             AdditionalPropertiesWithPatternsNotEmptyFalseValidator {
                 properties: compile_big_map(map, context)?,
@@ -892,7 +895,7 @@ impl<M: PropertiesValidatorsMap> Validate
                         // Valid for `properties`, check `patternProperties`
                         for (re, validators) in &self.patterns {
                             // If there is a match, then the value should match the sub-schema
-                            if re.is_match(property) {
+                            if re.is_match(property).unwrap_or(false) {
                                 is_valid_pattern_schema!(validators, schema, value)
                             }
                         }
@@ -924,7 +927,7 @@ impl<M: PropertiesValidatorsMap> Validate
                     errors.extend(
                         self.patterns
                             .iter()
-                            .filter(|(re, _)| re.is_match(property))
+                            .filter(|(re, _)| re.is_match(property).unwrap_or(false))
                             .flat_map(|(_, validators)| {
                                 validate!(validators, schema, value, instance_path, name)
                             }),
@@ -934,7 +937,7 @@ impl<M: PropertiesValidatorsMap> Validate
                     errors.extend(
                         self.patterns
                             .iter()
-                            .filter(|(re, _)| re.is_match(property))
+                            .filter(|(re, _)| re.is_match(property).unwrap_or(false))
                             .flat_map(|(_, validators)| {
                                 has_match = true;
                                 validate!(validators, schema, value, instance_path, property)
@@ -967,52 +970,55 @@ impl<M: PropertiesValidatorsMap> ToString
     }
 }
 #[inline]
-pub(crate) fn compile(
-    parent: &Map<String, Value>,
-    schema: &Value,
+pub(crate) fn compile<'a>(
+    parent: &'a Map<String, Value>,
+    schema: &'a Value,
     context: &CompilationContext,
-) -> Option<CompilationResult> {
+) -> Option<CompilationResult<'a>> {
     let properties = parent.get("properties");
     if let Some(patterns) = parent.get("patternProperties") {
         if let Value::Object(obj) = patterns {
             // Compile all patterns & their validators to avoid doing work in the `patternProperties` validator
-            let compiled_patterns = compile_patterns(obj, context).ok()?;
-            match schema {
-                Value::Bool(true) => None, // "additionalProperties" are "true" by default
-                Value::Bool(false) => {
-                    if let Some(properties) = properties {
-                        dynamic_map!(
-                            AdditionalPropertiesWithPatternsNotEmptyFalseValidator,
-                            properties,
-                            compiled_patterns,
-                            context
-                        )
-                    } else {
-                        Some(AdditionalPropertiesWithPatternsFalseValidator::compile(
-                            compiled_patterns,
-                        ))
+            if let Ok(compiled_patterns) = compile_patterns(obj, context) {
+                match schema {
+                    Value::Bool(true) => None, // "additionalProperties" are "true" by default
+                    Value::Bool(false) => {
+                        if let Some(properties) = properties {
+                            dynamic_map!(
+                                AdditionalPropertiesWithPatternsNotEmptyFalseValidator,
+                                properties,
+                                compiled_patterns,
+                                context
+                            )
+                        } else {
+                            Some(AdditionalPropertiesWithPatternsFalseValidator::compile(
+                                compiled_patterns,
+                            ))
+                        }
                     }
-                }
-                _ => {
-                    if let Some(properties) = properties {
-                        dynamic_map!(
-                            AdditionalPropertiesWithPatternsNotEmptyValidator,
-                            properties,
-                            schema,
-                            compiled_patterns,
-                            context
-                        )
-                    } else {
-                        Some(AdditionalPropertiesWithPatternsValidator::compile(
-                            schema,
-                            compiled_patterns,
-                            context,
-                        ))
+                    _ => {
+                        if let Some(properties) = properties {
+                            dynamic_map!(
+                                AdditionalPropertiesWithPatternsNotEmptyValidator,
+                                properties,
+                                schema,
+                                compiled_patterns,
+                                context
+                            )
+                        } else {
+                            Some(AdditionalPropertiesWithPatternsValidator::compile(
+                                schema,
+                                compiled_patterns,
+                                context,
+                            ))
+                        }
                     }
                 }
+            } else {
+                Some(Err(ValidationError::null_schema()))
             }
         } else {
-            Some(Err(CompilationError::SchemaError))
+            Some(Err(ValidationError::null_schema()))
         }
     } else {
         match schema {
@@ -1046,20 +1052,20 @@ pub(crate) fn compile(
 
 /// Create a vector of pattern-validators pairs.
 #[inline]
-fn compile_patterns(
-    obj: &Map<String, Value>,
+fn compile_patterns<'a>(
+    obj: &'a Map<String, Value>,
     context: &CompilationContext,
-) -> Result<PatternedValidators, CompilationError> {
+) -> Result<PatternedValidators, ValidationError<'a>> {
     let mut compiled_patterns = Vec::with_capacity(obj.len());
     for (pattern, subschema) in obj {
         if let Ok(compiled_pattern) = Regex::new(pattern) {
             if let Ok(validators) = compile_validators(subschema, context) {
                 compiled_patterns.push((compiled_pattern, validators));
             } else {
-                return Err(CompilationError::SchemaError);
+                return Err(ValidationError::schema(subschema));
             }
         } else {
-            return Err(CompilationError::SchemaError);
+            return Err(ValidationError::schema(subschema));
         }
     }
     Ok(compiled_patterns)
@@ -1110,12 +1116,12 @@ mod tests {
     }
 
     // `properties.bar` - should be a string
-    #[test_case(&json!({"foo": 3}), &["\'3\' is not of type \'string\'"])]
+    #[test_case(&json!({"foo": 3}), &["3 is not of type \"string\""])]
     // `additionalProperties` - extra keyword & not in `properties` / `patternProperties`
     #[test_case(&json!({"faz": 1}), &["Additional properties are not allowed (\'faz\' was unexpected)"])]
     #[test_case(&json!({"faz": 1, "haz": 1}), &["Additional properties are not allowed (\'faz\', \'haz\' were unexpected)"])]
     // `properties.foo` - should be a string & `patternProperties.^bar` - invalid
-    #[test_case(&json!({"foo": 3, "bar": 4}), &["4 is less than the minimum of 5", "\'3\' is not of type \'string\'"])]
+    #[test_case(&json!({"foo": 3, "bar": 4}), &["4 is less than the minimum of 5", "3 is not of type \"string\""])]
     // `properties.barbaz` - valid; `patternProperties.^bar` - invalid
     #[test_case(&json!({"barbaz": 3}), &["3 is less than the minimum of 5"])]
     // `patternProperties.^bar` (should be >=5)
@@ -1137,7 +1143,7 @@ mod tests {
       &json!({"bar": 4, "spam": 11, "foo": 3, "faz": 1}),
       &[
          "4 is less than the minimum of 5",
-         "\'3\' is not of type \'string\'",
+         "3 is not of type \"string\"",
          "11 is greater than the maximum of 10",
          "Additional properties are not allowed (\'faz\' was unexpected)"
       ]
@@ -1231,7 +1237,7 @@ mod tests {
     }
 
     // `properties` - should be a string
-    #[test_case(&json!({"foo": 3}), &["\'3\' is not of type \'string\'"])]
+    #[test_case(&json!({"foo": 3}), &["3 is not of type \"string\""])]
     // `additionalProperties` - extra keyword & not in `properties`
     #[test_case(&json!({"faz": "a"}), &["Additional properties are not allowed (\'faz\' was unexpected)"])]
     // All combined
@@ -1239,7 +1245,7 @@ mod tests {
       &json!(
         {"foo": 3, "faz": "a"}),
         &[
-          "\'3\' is not of type \'string\'",
+          "3 is not of type \"string\"",
           "Additional properties are not allowed (\'faz\' was unexpected)",
         ]
     )]
@@ -1275,16 +1281,16 @@ mod tests {
     }
 
     // `properties` - should be a string
-    #[test_case(&json!({"foo": 3}), &["\'3\' is not of type \'string\'"])]
+    #[test_case(&json!({"foo": 3}), &["3 is not of type \"string\""])]
     // `additionalProperties` - should be an integer
-    #[test_case(&json!({"bar": "a"}), &["\'\"a\"\' is not of type \'integer\'"])]
+    #[test_case(&json!({"bar": "a"}), &["\"a\" is not of type \"integer\""])]
     // All combined
     #[test_case(
       &json!(
         {"foo": 3, "bar": "a"}),
         &[
-          "\'\"a\"\' is not of type \'integer\'",
-          "\'3\' is not of type \'string\'"
+          "\"a\" is not of type \"integer\"",
+          "3 is not of type \"string\""
         ]
     )]
     fn schema_4_invalid(instance: &Value, expected: &[&str]) {
@@ -1334,12 +1340,12 @@ mod tests {
     }
 
     // `properties.bar` - should be a string
-    #[test_case(&json!({"foo": 3}), &["\'3\' is not of type \'string\'"])]
+    #[test_case(&json!({"foo": 3}), &["3 is not of type \"string\""])]
     // `additionalProperties` - extra keyword that doesn't match `additionalProperties`
-    #[test_case(&json!({"faz": "a"}), &["\'\"a\"\' is not of type \'integer\'"])]
-    #[test_case(&json!({"faz": "a", "haz": "a"}), &["\'\"a\"\' is not of type \'integer\'", "\'\"a\"\' is not of type \'integer\'"])]
+    #[test_case(&json!({"faz": "a"}), &["\"a\" is not of type \"integer\""])]
+    #[test_case(&json!({"faz": "a", "haz": "a"}), &["\"a\" is not of type \"integer\"", "\"a\" is not of type \"integer\""])]
     // `properties.foo` - should be a string & `patternProperties.^bar` - invalid
-    #[test_case(&json!({"foo": 3, "bar": 4}), &["4 is less than the minimum of 5", "\'3\' is not of type \'string\'"])]
+    #[test_case(&json!({"foo": 3, "bar": 4}), &["4 is less than the minimum of 5", "3 is not of type \"string\""])]
     // `properties.barbaz` - valid; `patternProperties.^bar` - invalid
     #[test_case(&json!({"barbaz": 3}), &["3 is less than the minimum of 5"])]
     // `patternProperties.^bar` (should be >=5)
@@ -1361,8 +1367,8 @@ mod tests {
       &json!({"bar": 4, "spam": 11, "foo": 3, "faz": "a", "fam": 42}),
       &[
          "4 is less than the minimum of 5",
-         "\'\"a\"\' is not of type \'integer\'",
-         "\'3\' is not of type \'string\'",
+         "\"a\" is not of type \"integer\"",
+         "3 is not of type \"string\"",
          "11 is greater than the maximum of 10",
       ]
     )]
@@ -1405,10 +1411,10 @@ mod tests {
     }
 
     // `additionalProperties` - extra keyword that doesn't match `additionalProperties`
-    #[test_case(&json!({"faz": "a"}), &["\'\"a\"\' is not of type \'integer\'"])]
-    #[test_case(&json!({"faz": "a", "haz": "a"}), &["\'\"a\"\' is not of type \'integer\'", "\'\"a\"\' is not of type \'integer\'"])]
+    #[test_case(&json!({"faz": "a"}), &["\"a\" is not of type \"integer\""])]
+    #[test_case(&json!({"faz": "a", "haz": "a"}), &["\"a\" is not of type \"integer\"", "\"a\" is not of type \"integer\""])]
     // `additionalProperties` - should be an integer & `patternProperties.^bar` - invalid
-    #[test_case(&json!({"foo": "a", "bar": 4}), &["4 is less than the minimum of 5", "\'\"a\"\' is not of type \'integer\'"])]
+    #[test_case(&json!({"foo": "a", "bar": 4}), &["4 is less than the minimum of 5", "\"a\" is not of type \"integer\""])]
     // `patternProperties.^bar` (should be >=5)
     #[test_case(&json!({"bar": 4}), &["4 is less than the minimum of 5"])]
     // `patternProperties.spam$` (should be <=10)
@@ -1428,7 +1434,7 @@ mod tests {
       &json!({"bar": 4, "spam": 11, "faz": "a", "fam": 42}),
       &[
          "4 is less than the minimum of 5",
-         "\'\"a\"\' is not of type \'integer\'",
+         "\"a\" is not of type \"integer\"",
          "11 is greater than the maximum of 10",
       ]
     )]
