@@ -1,19 +1,24 @@
 use crate::{
     compilation::{compile_validators, context::CompilationContext, JSONSchema},
-    error::{error, no_error, CompilationError, ErrorIterator, ValidationError},
-    keywords::{format_vec_of_validators, CompilationResult, Validators},
+    error::{error, no_error, ErrorIterator, ValidationError},
+    keywords::{format_vec_of_validators, Validators},
     paths::InstancePath,
     validator::Validate,
 };
 use serde_json::{Map, Value};
 
+use super::CompilationResult;
+
 pub(crate) struct AnyOfValidator {
     schemas: Vec<Validators>,
 }
 
 impl AnyOfValidator {
     #[inline]
-    pub(crate) fn compile(schema: &Value, context: &CompilationContext) -> CompilationResult {
+    pub(crate) fn compile<'a>(
+        schema: &'a Value,
+        context: &CompilationContext,
+    ) -> CompilationResult<'a> {
         if let Value::Array(items) = schema {
             let mut schemas = Vec::with_capacity(items.len());
             for item in items {
@@ -22,7 +27,7 @@ impl AnyOfValidator {
             }
             Ok(Box::new(AnyOfValidator { schemas }))
         } else {
-            Err(CompilationError::SchemaError)
+            Err(ValidationError::schema(schema))
         }
     }
 }
@@ -60,10 +65,10 @@ impl ToString for AnyOfValidator {
     }
 }
 #[inline]
-pub(crate) fn compile(
-    _: &Map<String, Value>,
-    schema: &Value,
+pub(crate) fn compile<'a>(
+    _: &'a Map<String, Value>,
+    schema: &'a Value,
     context: &CompilationContext,
-) -> Option<CompilationResult> {
+) -> Option<CompilationResult<'a>> {
     Some(AnyOfValidator::compile(schema, context))
 }
