@@ -13,7 +13,10 @@ pub(crate) struct ContainsValidator {
 
 impl ContainsValidator {
     #[inline]
-    pub(crate) fn compile(schema: &Value, context: &CompilationContext) -> CompilationResult {
+    pub(crate) fn compile<'a>(
+        schema: &'a Value,
+        context: &CompilationContext,
+    ) -> CompilationResult<'a> {
         Ok(Box::new(ContainsValidator {
             validators: compile_validators(schema, context)?,
         }))
@@ -68,10 +71,10 @@ impl ToString for ContainsValidator {
 }
 
 #[inline]
-pub(crate) fn compile(
-    _: &Map<String, Value>,
-    schema: &Value,
+pub(crate) fn compile<'a>(
+    _: &'a Map<String, Value>,
+    schema: &'a Value,
     context: &CompilationContext,
-) -> Option<CompilationResult> {
+) -> Option<CompilationResult<'a>> {
     Some(ContainsValidator::compile(schema, context))
 }
