@@ -1,14 +1,14 @@
 //! Validator for `format` keyword.
 use crate::{
     compilation::{context::CompilationContext, JSONSchema},
-    error::{error, no_error, CompilationError, ErrorIterator, ValidationError},
-    keywords::CompilationResult,
+    error::{error, no_error, ErrorIterator, ValidationError},
+    keywords::{pattern, CompilationResult},
     paths::InstancePath,
     validator::Validate,
     Draft,
 };
 use chrono::{DateTime, NaiveDate};
-use regex::Regex;
+use fancy_regex::Regex;
 use serde_json::{Map, Value};
 
 use std::{net::IpAddr, str::FromStr};
@@ -38,7 +38,7 @@ macro_rules! format_validator {
     ($validator:ident, $format_name:tt) => {
         struct $validator {}
         impl $validator {
-            pub(crate) fn compile() -> CompilationResult {
+            pub(crate) fn compile<'a>() -> CompilationResult<'a> {
                 Ok(Box::new($validator {}))
             }
         }
@@ -82,7 +82,9 @@ impl Validate for DateValidator {
                 // Padding with zeroes is ignored by the underlying parser. The most efficient
                 // way to check it will be to use a custom parser that won't ignore zeroes,
                 // but this regex will do the trick and costs ~20% extra time in this validator.
-                DATE_RE.is_match(item.as_str())
+                DATE_RE
+                    .is_match(item.as_str())
+                    .expect("Simple DATE_RE pattern")
             } else {
                 false
             }
@@ -102,12 +104,32 @@ impl Validate for DateTimeValidator {
         }
     }
 }
+fn is_valid_email(email: &str) -> bool {
+    if let Some('.') = email.chars().next() {
+        // dot before local part is not valid
+        return false;
+    }
+    // This loop exits early if it finds `@`.
+    // Therefore, match arms examine only the local part
+    for (a, b) in email.chars().zip(email.chars().skip(1)) {
+        match (a, b) {
+            // two subsequent dots inside local part are not valid
+            // dot after local part is not valid
+            ('.', '.') | ('.', '@') => return false,
+            // The domain part is not validated for simplicity
+            (_, '@') => return true,
+            (_, _) => continue,
+        }
+    }
+    false
+}
+
 format_validator!(EmailValidator, "email");
 impl Validate for EmailValidator {
     validate!("email");
     fn is_valid(&self, _: &JSONSchema, instance: &Value) -> bool {
         if let Value::String(item) = instance {
-            item.contains('@')
+            is_valid_email(item)
         } else {
             true
         }
@@ -118,7 +140,7 @@ impl Validate for IDNEmailValidator {
     validate!("idn-email");
     fn is_valid(&self, _: &JSONSchema, instance: &Value) -> bool {
         if let Value::String(item) = instance {
-            item.contains('@')
+            is_valid_email(item)
         } else {
             true
         }
@@ -219,7 +241,9 @@ impl Validate for IRIReferenceValidator {
     validate!("iri-reference");
     fn is_valid(&self, _: &JSONSchema, instance: &Value) -> bool {
         if let Value::String(item) = instance {
-            IRI_REFERENCE_RE.is_match(item)
+            IRI_REFERENCE_RE
+                .is_match(item)
+                .expect("Simple IRI_REFERENCE_RE pattern")
         } else {
             true
         }
@@ -230,7 +254,9 @@ impl Validate for JSONPointerValidator {
     validate!("json-pointer");
     fn is_valid(&self, _: &JSONSchema, instance: &Value) -> bool {
         if let Value::String(item) = instance {
-            JSON_POINTER_RE.is_match(item)
+            JSON_POINTER_RE
+                .is_match(item)
+                .expect("Simple JSON_POINTER_RE pattern")
         } else {
             true
         }
@@ -241,7 +267,7 @@ impl Validate for RegexValidator {
     validate!("regex");
     fn is_valid(&self, _: &JSONSchema, instance: &Value) -> bool {
         if let Value::String(item) = instance {
-            Regex::new(item).is_ok()
+            pattern::convert_regex(item).is_ok()
         } else {
             true
         }
@@ -252,7 +278,9 @@ impl Validate for RelativeJSONPointerValidator {
     validate!("relative-json-pointer");
     fn is_valid(&self, _: &JSONSchema, instance: &Value) -> bool {
         if let Value::String(item) = instance {
-            RELATIVE_JSON_POINTER_RE.is_match(item)
+            RELATIVE_JSON_POINTER_RE
+                .is_match(item)
+                .expect("Simple RELATIVE_JSON_POINTER_RE pattern")
         } else {
             true
         }
@@ -263,7 +291,7 @@ impl Validate for TimeValidator {
     validate!("time");
     fn is_valid(&self, _: &JSONSchema, instance: &Value) -> bool {
         if let Value::String(item) = instance {
-            TIME_RE.is_match(item)
+            TIME_RE.is_match(item).expect("Simple TIME_RE pattern")
         } else {
             true
         }
@@ -274,7 +302,9 @@ impl Validate for URIReferenceValidator {
     validate!("uri-reference");
     fn is_valid(&self, _: &JSONSchema, instance: &Value) -> bool {
         if let Value::String(item) = instance {
-            URI_REFERENCE_RE.is_match(item)
+            URI_REFERENCE_RE
+                .is_match(item)
+                .expect("Simple URI_REFERENCE_RE pattern")
         } else {
             true
         }
@@ -285,7 +315,9 @@ impl Validate for URITemplateValidator {
     validate!("uri-template");
     fn is_valid(&self, _: &JSONSchema, instance: &Value) -> bool {
         if let Value::String(item) = instance {
-            URI_TEMPLATE_RE.is_match(item)
+            URI_TEMPLATE_RE
+                .is_match(item)
+                .expect("Simple URI_TEMPLATE_RE pattern")
         } else {
             true
         }
@@ -293,11 +325,11 @@ impl Validate for URITemplateValidator {
 }
 
 #[inline]
-pub(crate) fn compile(
-    _: &Map<String, Value>,
-    schema: &Value,
+pub(crate) fn compile<'a>(
+    _: &'a Map<String, Value>,
+    schema: &'a Value,
     context: &CompilationContext,
-) -> Option<CompilationResult> {
+) -> Option<CompilationResult<'a>> {
     if let Value::String(format) = schema {
         let draft_version = context.config.draft();
         match format.as_str() {
@@ -333,7 +365,7 @@ pub(crate) fn compile(
             _ => None,
         }
     } else {
-        Some(Err(CompilationError::SchemaError))
+        Some(Err(ValidationError::schema(schema)))
     }
 }
 
@@ -349,4 +381,13 @@ mod tests {
         let compiled = JSONSchema::compile(&schema).unwrap();
         assert!(compiled.is_valid(&instance))
     }
+
+    #[test]
+    fn ecma_regex() {
+        // See GH-230
+        let schema = json!({"format": "regex", "type": "string"});
+        let instance = json!("^\\cc$");
+        let compiled = JSONSchema::compile(&schema).unwrap();
+        assert!(compiled.is_valid(&instance))
+    }
 }
