@@ -1,6 +1,6 @@
 use crate::{
     compilation::{context::CompilationContext, JSONSchema},
-    error::{error, no_error, CompilationError, ErrorIterator, ValidationError},
+    error::{error, no_error, ErrorIterator, ValidationError},
     keywords::{type_, CompilationResult},
     paths::InstancePath,
     primitive_type::{PrimitiveType, PrimitiveTypesBitMap},
@@ -23,10 +23,10 @@ impl MultipleTypesValidator {
                     if let Ok(primitive_type) = PrimitiveType::try_from(string.as_str()) {
                         types |= primitive_type;
                     } else {
-                        return Err(CompilationError::SchemaError);
+                        return Err(ValidationError::schema(item));
                     }
                 }
-                _ => return Err(CompilationError::SchemaError),
+                _ => return Err(ValidationError::schema(item)),
             }
         }
         Ok(Box::new(MultipleTypesValidator { types }))
@@ -82,7 +82,7 @@ pub(crate) struct IntegerTypeValidator {}
 
 impl IntegerTypeValidator {
     #[inline]
-    pub(crate) fn compile() -> CompilationResult {
+    pub(crate) fn compile<'a>() -> CompilationResult<'a> {
         Ok(Box::new(IntegerTypeValidator {}))
     }
 }
@@ -125,11 +125,11 @@ fn is_integer(num: &Number) -> bool {
 }
 
 #[inline]
-pub(crate) fn compile(
-    _: &Map<String, Value>,
-    schema: &Value,
+pub(crate) fn compile<'a>(
+    _: &'a Map<String, Value>,
+    schema: &'a Value,
     _: &CompilationContext,
-) -> Option<CompilationResult> {
+) -> Option<CompilationResult<'a>> {
     match schema {
         Value::String(item) => compile_single_type(item.as_str()),
         Value::Array(items) => {
@@ -137,17 +137,17 @@ pub(crate) fn compile(
                 if let Some(Value::String(item)) = items.iter().next() {
                     compile_single_type(item.as_str())
                 } else {
-                    Some(Err(CompilationError::SchemaError))
+                    Some(Err(ValidationError::schema(schema)))
                 }
             } else {
                 Some(MultipleTypesValidator::compile(items))
             }
         }
-        _ => Some(Err(CompilationError::SchemaError)),
+        _ => Some(Err(ValidationError::schema(schema))),
     }
 }
 
-fn compile_single_type(item: &str) -> Option<CompilationResult> {
+fn compile_single_type<'a>(item: &str) -> Option<CompilationResult<'a>> {
     match PrimitiveType::try_from(item) {
         Ok(PrimitiveType::Array) => Some(type_::ArrayTypeValidator::compile()),
         Ok(PrimitiveType::Boolean) => Some(type_::BooleanTypeValidator::compile()),
@@ -156,6 +156,6 @@ fn compile_single_type(item: &str) -> Option<CompilationResult> {
         Ok(PrimitiveType::Number) => Some(type_::NumberTypeValidator::compile()),
         Ok(PrimitiveType::Object) => Some(type_::ObjectTypeValidator::compile()),
         Ok(PrimitiveType::String) => Some(type_::StringTypeValidator::compile()),
-        Err(()) => Some(Err(CompilationError::SchemaError)),
+        Err(()) => Some(Err(ValidationError::null_schema())),
     }
 }
