@@ -1,22 +1,22 @@
 use crate::{
     compilation::{context::CompilationContext, JSONSchema},
-    error::{error, no_error, CompilationError, ErrorIterator, ValidationError},
+    error::{error, no_error, ErrorIterator, ValidationError},
     keywords::CompilationResult,
     paths::InstancePath,
     validator::Validate,
 };
-use regex::{Captures, Regex};
 use serde_json::{Map, Value};
 
 use std::ops::Index;
 
 lazy_static::lazy_static! {
-    static ref CONTROL_GROUPS_RE: Regex = Regex::new(r"\\c[A-Za-z]").expect("Is a valid regex");
+    // Use regex::Regex here to take advantage of replace_all method not available in fancy_regex::Regex
+    static ref CONTROL_GROUPS_RE: regex::Regex = regex::Regex::new(r"\\c[A-Za-z]").expect("Is a valid regex");
 }
 
 pub(crate) struct PatternValidator {
     original: String,
-    pattern: Regex,
+    pattern: fancy_regex::Regex,
 }
 
 impl PatternValidator {
@@ -24,13 +24,16 @@ impl PatternValidator {
     pub(crate) fn compile(pattern: &Value) -> CompilationResult {
         match pattern {
             Value::String(item) => {
-                let pattern = convert_regex(item)?;
+                let pattern = match convert_regex(item) {
+                    Ok(r) => r,
+                    Err(_) => return Err(ValidationError::schema(pattern)),
+                };
                 Ok(Box::new(PatternValidator {
                     original: item.clone(),
                     pattern,
                 }))
             }
-            _ => Err(CompilationError::SchemaError),
+            _ => Err(ValidationError::schema(pattern)),
         }
     }
 }
@@ -43,12 +46,23 @@ impl Validate for PatternValidator {
         instance_path: &InstancePath,
     ) -> ErrorIterator<'a> {
         if let Value::String(item) = instance {
-            if !self.pattern.is_match(item) {
-                return error(ValidationError::pattern(
-                    instance_path.into(),
-                    instance,
-                    self.original.clone(),
-                ));
+            match self.pattern.is_match(item) {
+                Ok(is_match) => {
+                    if !is_match {
+                        return error(ValidationError::pattern(
+                            instance_path.into(),
+                            instance,
+                            self.original.clone(),
+                        ));
+                    }
+                }
+                Err(e) => {
+                    return error(ValidationError::backtrack_limit(
+                        instance_path.into(),
+                        instance,
+                        e,
+                    ));
+                }
             }
         }
         no_error()
@@ -56,9 +70,7 @@ impl Validate for PatternValidator {
 
     fn is_valid(&self, _: &JSONSchema, instance: &Value) -> bool {
         if let Value::String(item) = instance {
-            if !self.pattern.is_match(item) {
-                return false;
-            }
+            return self.pattern.is_match(item).unwrap_or(false);
         }
         true
     }
@@ -71,7 +83,7 @@ impl ToString for PatternValidator {
 }
 
 // ECMA 262 has differences
-fn convert_regex(pattern: &str) -> Result<Regex, regex::Error> {
+pub(crate) fn convert_regex(pattern: &str) -> Result<fancy_regex::Regex, fancy_regex::Error> {
     // replace control chars
     let new_pattern = CONTROL_GROUPS_RE.replace_all(pattern, replace_control_group);
     let mut out = String::with_capacity(new_pattern.len());
@@ -110,11 +122,11 @@ fn convert_regex(pattern: &str) -> Result<Regex, regex::Error> {
             out.push(current);
         }
     }
-    Regex::new(&out)
+    fancy_regex::Regex::new(&out)
 }
 
 #[allow(clippy::integer_arithmetic)]
-fn replace_control_group(captures: &Captures) -> String {
+fn replace_control_group(captures: &regex::Captures) -> String {
     // There will be no overflow, because the minimum value is 65 (char 'A')
     ((captures
         .index(0)
@@ -128,17 +140,18 @@ fn replace_control_group(captures: &Captures) -> String {
 }
 
 #[inline]
-pub(crate) fn compile(
-    _: &Map<String, Value>,
-    schema: &Value,
+pub(crate) fn compile<'a>(
+    _: &'a Map<String, Value>,
+    schema: &'a Value,
     _: &CompilationContext,
-) -> Option<CompilationResult> {
+) -> Option<CompilationResult<'a>> {
     Some(PatternValidator::compile(schema))
 }
 
 #[cfg(test)]
 mod tests {
     use super::*;
+    use serde_json::{json, Value};
     use test_case::test_case;
 
     #[test_case(r"^[\w\-\.\+]+$", "CC-BY-4.0", true)]
@@ -147,7 +160,10 @@ mod tests {
     #[test_case(r"\\w", r"\w", true)]
     fn regex_matches(pattern: &str, text: &str, is_matching: bool) {
         let compiled = convert_regex(pattern).expect("A valid regex");
-        assert_eq!(compiled.is_match(text), is_matching);
+        assert_eq!(
+            compiled.is_match(text).expect("A valid pattern"),
+            is_matching
+        );
     }
 
     #[test_case(r"\")]
@@ -155,4 +171,16 @@ mod tests {
     fn invalid_escape_sequences(pattern: &str) {
         assert!(convert_regex(pattern).is_err())
     }
+
+    #[test_case("^(?!eo:)", "eo:bands", false)]
+    #[test_case("^(?!eo:)", "proj:epsg", true)]
+    fn negative_lookbehind_match(pattern: &str, text: &str, is_matching: bool) {
+        let pattern = Value::String(pattern.into());
+        let text = Value::String(text.into());
+        let schema = json!({});
+
+        let compiled = PatternValidator::compile(&pattern).unwrap();
+        let schema = JSONSchema::compile(&schema).unwrap();
+        assert_eq!(compiled.is_valid(&schema, &text), is_matching,)
+    }
 }
